@@ -6,7 +6,7 @@ BEGIN {
     use Excel::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = '0.24';
+    $VERSION  = '0.25';
     @ISA      = qw( Excel::Template::Base );
 }
 
@@ -202,9 +202,17 @@ sub parse_xml
  
         push @parms, Base => $dirname;
 
-        open( INFILE, "<$file" )
-            || die "Cannot open '$file' for reading: $!\n";
-
+        eval q{
+            open( INFILE, '<', $file )
+                || die "Cannot open '$file' for reading: $!\n";
+        }; if ( $@ ) {
+           if ( $@ =~ /Too many arguments for open/ ) {
+                open( INFILE, "< $file" )
+                    || die "Cannot open '$file' for reading: $!\n";
+            } else {
+                die $@;
+            }
+        }
     }
 
     my $parser = XML::Parser->new( @parms );
